<?php

namespace Litecms\Pep\Http\Controllers;

use Exception;
use Litepie\Http\Controllers\ResourceController as BaseController;
use Litecms\Pep\Forms\Pep as PepForm;
use Litecms\Pep\Http\Requests\PepResourceRequest;
use Litecms\Pep\Http\Resources\PepResource;
use Litecms\Pep\Http\Resources\PepsCollection;
use Litecms\Pep\Models\Pep;
use Litecms\Pep\Actions\PepAction;
use Litecms\Pep\Actions\PepActions;


/**
 * Resource controller class for pep.
 */
class PepResourceController extends BaseController
{

    /**
     * Initialize pep resource controller.
     *
     *
     * @return null
     */
    public function __construct()
    {
        parent::__construct();
        $this->form = PepForm::grouped(false)
                        ->setAttributes()
                        ->toArray();
        $this->modules = $this->modules(config('litecms.pep.modules'), 'pep', guard_url('pep'));
    }

    /**
     * Display a list of pep.
     *
     * @return Response
     */
    public function index(PepResourceRequest $request)
    {
        $request = $request->all();
        $page = PepActions::run('paginate', $request);

        $data = new PepsCollection($page);

        $form = $this->form;
        $modules = $this->modules;

        return $this->response->setMetaTitle(trans('pep::pep.names'))
            ->view('pep::pep.index')
            ->data(compact('data', 'modules', 'form'))
            ->output();

    }

    /**
     * Display pep.
     *
     * @param Request $request
     * @param Model   $pep
     *
     * @return Response
     */
    public function show(PepResourceRequest $request, Pep $model)
    {
        $form = $this->form;
        $modules = $this->modules;
        $data = new PepResource($model);
        return $this->response
            ->setMetaTitle(trans('app.view') . ' ' . trans('pep::pep.name'))
            ->data(compact('data', 'form', 'modules'))
            ->view('pep::pep.show')
            ->output();
    }

    /**
     * Show the form for creating a new pep.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function create(PepResourceRequest $request, Pep $model)
    {
        $form = $this->form;
        $modules = $this->modules;
        $data = new PepResource($model);
        return $this->response->setMetaTitle(trans('app.new') . ' ' . trans('pep::pep.name'))
            ->view('pep::pep.create')
            ->data(compact('data', 'form', 'modules'))
            ->output();

    }

    /**
     * Create new pep.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(PepResourceRequest $request, Pep $model)
    {
        try {
            $request = $request->all();
            $model = PepAction::run('store', $model, $request);
            $data = new PepResource($model);
            return $this->response->message(trans('messages.success.created', ['Module' => trans('pep::pep.name')]))
                ->code(204)
                ->data(compact('data'))
                ->status('success')
                ->url(guard_url('pep/pep/' . $model->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('/pep/pep'))
                ->redirect();
        }

    }

    /**
     * Show pep for editing.
     *
     * @param Request $request
     * @param Model   $pep
     *
     * @return Response
     */
    public function edit(PepResourceRequest $request, Pep $model)
    {
        $form = $this->form;
        $modules = $this->modules;
        $data = new PepResource($model);
        // return view('pep::pep.edit', compact('data', 'form', 'modules'));

        return $this->response->setMetaTitle(trans('app.edit') . ' ' . trans('pep::pep.name'))
            ->view('pep::pep.edit')
            ->data(compact('data', 'form', 'modules'))
            ->output();

    }

    /**
     * Update the pep.
     *
     * @param Request $request
     * @param Model   $pep
     *
     * @return Response
     */
    public function update(PepResourceRequest $request, Pep $model)
    {
        try {
            $request = $request->all();
            $model = PepAction::run('update', $model, $request);
            $data = new PepResource($model);

            return $this->response->message(trans('messages.success.updated', ['Module' => trans('pep::pep.name')]))
                ->code(204)
                ->status('success')
                ->data(compact('data'))
                ->url(guard_url('pep/pep/' . $model->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('pep/pep/' .  $model->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove the pep.
     *
     * @param Model   $pep
     *
     * @return Response
     */
    public function destroy(PepResourceRequest $request, Pep $model)
    {
        try {

            $request = $request->all();
            $model = PepAction::run('destroy', $model, $request);
            $data = new PepResource($model);

            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('pep::pep.name')]))
                ->code(202)
                ->status('success')
                ->data(compact('data'))
                ->url(guard_url('pep/pep/0'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('pep/pep/' .  $model->getRouteKey()))
                ->redirect();
        }

    }
}
